
###########################################
test_samples.undocumented_option_no_default
###########################################

.. module:: test_samples.undocumented_option_no_default


.. data:: "UNDOCUMENTED_OPTION_NO_DEFAULT"


   .. note:: 

      
      This variable is a user-editable option,
      meaning it appears within the cache and can be
      edited on the command line by the :code:`-D` flag.
      

   

   :Help text: "This is an undocumented option and it doesn't have a default value"

   :Default value: OFF

   :type: bool

